@@ -6,82 +6,87 @@
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Copy</source>
-        <translation type="unfinished">Kopioi</translation>
+        <translation>Kopioi</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Rename</source>
-        <translation type="unfinished">Nimeä</translation>
+        <translation>Nimeä</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Move</source>
-        <translation type="unfinished">Siirrä</translation>
+        <translation>Siirrä</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Delete</source>
-        <translation type="unfinished">Poista</translation>
+        <translation>Poista</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Edit</source>
-        <translation type="unfinished">Muokkaa</translation>
+        <translation>Muokkaa</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Share</source>
-        <translation type="unfinished">Jaa</translation>
+        <translation>Jaa</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Compress</source>
-        <translation type="unfinished">Pakkaa</translation>
+        <translation>Pakkaa</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Documents</source>
-        <translation type="unfinished">Dokumentit</translation>
+        <translation>Dokumentit</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Images</source>
-        <translation type="unfinished">Kuvat</translation>
+        <translation>Kuvat</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Camera</source>
-        <translation type="unfinished">Kamera</translation>
+        <translation>Kamera</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Sounds</source>
-        <translation type="unfinished">Äänet</translation>
+        <translation>Äänet</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Videos</source>
-        <translation type="unfinished">Videot</translation>
+        <translation>Videot</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Added to Clipboard</source>
-        <translation type="unfinished">Lisätty leikepöydälle</translation>
+        <translation>Lisätty leikepöydälle</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>ERROR: Nothing selected to paste</source>
-        <translation type="unfinished">VIRHE: Ei valittu liittää</translation>
+        <translation>VIRHE: Ei liitettävää</translation>
     </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Not enough space to proceed.</source>
-        <translation type="unfinished">Ei tilaa toiminnon suoritukselle.</translation>
+        <translation>Ei tilaa toiminnon suoritukselle.</translation>
     </message>
     <message>
         <location filename="../error.cpp" line="10"/>
-        <source>You don't have permissions to proceed.</source>
-        <translation type="unfinished">Ei oikeuksia toiminnon suoritukselle.</translation>
+        <source>You don&apos;t have permissions to proceed.</source>
+        <translation>Ei oikeuksia toiminnon suoritukselle.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>About</source>
+        <translation>Tietoja</translation>
     </message>
 </context>
 <context>
@@ -89,7 +94,7 @@
     <message>
         <location filename="../bookwindow.cpp" line="10"/>
         <source>Bookmarks</source>
-        <translation type="unfinished">Kirjanmerkit</translation>
+        <translation>Kirjanmerkit</translation>
     </message>
 </context>
 <context>
@@ -97,33 +102,38 @@
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Home folder</source>
-        <translation type="unfinished">Kotihakemisto</translation>
+        <translation>Kotihakemistol</translation>
     </message>
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Compress destination</source>
-        <translation type="unfinished">Pakkauksen kohde</translation>
+        <translation>Pakkauksen kohde</translation>
+    </message>
+    <message>
+        <location filename="../home.cpp" line="10"/>
+        <source>Extract destination</source>
+        <translation>Purkamisen kohde</translation>
     </message>
 </context>
 <context>
-    <name>ClipWindow</name>
+    <name>Clipboard</name>
     <message>
-        <location filename="../clipwindow.cpp" line="10"/>
+        <location filename="../clipboard.cpp" line="10"/>
         <source>Clipboard</source>
-        <translation type="unfinished">Leikepöytä</translation>
+        <translation>Leikepöytä</translation>
     </message>
 </context>
 <context>
     <name>Bookmarks</name>
     <message>
         <location filename="../bookmarks.cpp" line="10"/>
-        <source>Booksmarks</source>
-        <translation type="unfinished">Kirjanmerkit</translation>
+        <source>Bookmarks</source>
+        <translation>Kirjanmerkit</translation>
     </message>
     <message>
         <location filename="../bookmarks.cpp" line="10"/>
         <source>Delete</source>
-        <translation type="unfinished">Poista</translation>
+        <translation>Poista</translation>
     </message>
 </context>
 <context>
@@ -131,27 +141,27 @@
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Tools</source>
-        <translation type="unfinished">Työkalut</translation>
+        <translation>Työkalut</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Add to Bookmarks</source>
-        <translation type="unfinished">Lisää kirjanmerkki</translation>
+        <translation>Lisää kirjanmerkki</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Create new folder</source>
-        <translation type="unfinished">Luo uusi hakemisto</translation>
+        <translation>Luo uusi hakemisto</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Create new document</source>
-        <translation type="unfinished">Luo uusi dokumentti</translation>
+        <translation>Luo uusi dokumentti</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
-        <translation type="unfinished">Järjestä</translation>
+        <translation>Järjestä</translation>
     </message>
 </context>
 <context>
@@ -159,17 +169,17 @@
     <message>
         <location filename="../share.cpp" line="10"/>
         <source>Share</source>
-        <translation type="unfinished">Jaa</translation>
+        <translation>Jaa</translation>
     </message>
     <message>
         <location filename="../share.cpp" line="10"/>
         <source>Send via bluetooth</source>
-        <translation type="unfinished">Jaa bluetoothilla</translation>
+        <translation>Jaa bluetoothilla</translation>
     </message>
     <message>
         <location filename="../share.cpp" line="10"/>
         <source>Send via e-mail</source>
-        <translation type="unfinished">Jaa sähköpostilla</translation>
+        <translation>Jaa sähköpostilla</translation>
     </message>
 </context>
 <context>
@@ -177,122 +187,122 @@
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>%1 of %2 completed</source>
-        <translation type="unfinished">%1 valmis %2:sta</translation>
+        <translation>%1 valmis %2:sta</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Warning</source>
-        <translation type="unfinished">Varoitus</translation>
+        <translation>Varoitus</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Copy Warning</source>
-        <translation type="unfinished">Varoitus (kopiointi)</translation>
+        <translation>Varoitus (kopiointi)</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source doesn&apos;t exist.</source>
-        <translation type="unfinished">Lähdetiedostoa ei ole.</translation>
+        <translation>Lähdetiedostoa ei ole.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>No enough space for copy the file.</source>
-        <translation type="unfinished">Ei tarpeeksi tilaa kopioinnille.</translation>
+        <translation>Ei tarpeeksi tilaa kopioinnille.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source file is a directory. Omitting source directory.</source>
-        <translation type="unfinished">Lähdetiedosto on hakemisto. Lähdekansio ohitetaan.</translation>
+        <translation>Lähdetiedosto on hakemisto. Lähdekansio ohitetaan.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source directory is a file. Omitting source file.</source>
-        <translation type="unfinished">Lähdehakemisto on tiedosto. Lähdekansio ohitetaan.</translation>
+        <translation>Lähdehakemisto on tiedosto. Lähdekansio ohitetaan.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Path to destination does not exist.</source>
-        <translation type="unfinished">Kohteen polkua ei ole.</translation>
+        <translation>Kohteen polkua ei ole.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot create destination directory.</source>
-        <translation type="unfinished">Kohdehakemistoa ei voi luoda.</translation>
+        <translation>&gt;Kohdehakemistoa ei voi luoda.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot open source file. Please check permissions.</source>
-        <translation type="unfinished">Lähdetiedostoa ei voi avata. Tarkista oikeudet.</translation>
+        <translation>Lähdetiedostoa ei voi avata. Tarkista oikeudet.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot open destination file. Please check permissions.</source>
-        <translation type="unfinished">Kohdetiedostoa ei voi avata. Tarkista oikeudet.</translation>
+        <translation>Kohdetiedostoa ei voi avata. Tarkista oikeudet.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Force: Cannot remove destination file.</source>
-        <translation type="unfinished">Kohdetiedostoa ei voi poistaa.</translation>
+        <translation>Kohdetiedostoa ei voi poistaa.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot create symbolic link targeting to source.</source>
-        <translation type="unfinished">Symbolista linkkiä lähdetiedostoon ei voitu luoda.</translation>
+        <translation>Symbolista linkkiä lähdetiedostoon ei voitu luoda.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot read source file.</source>
-        <translation type="unfinished">Lähdetiedostoa ei voi lukea.</translation>
+        <translation>Lähdetiedostoa ei voi lukea.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot write destination file.</source>
-        <translation type="unfinished">Kohdetiedostoa ei voi kirjoittaa.</translation>
+        <translation>Kohdetiedostoa ei voi kirjoittaa.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot remove source.</source>
-        <translation type="unfinished">Lähdetiedostoa ei voi poistaa.</translation>
+        <translation>Lähdetiedostoa ei voi poistaa.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>100% of %1 (Done)</source>
-        <translation type="unfinished">100% %1:sta (valmis)</translation>
+        <translation>100% %1:sta (valmis)</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Copying...</source>
-        <translation type="unfinished">Kopioidaan...</translation>
+        <translation>Kopioidaan...</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>%1% of %2 (%3)</source>
-        <translation type="unfinished">%1% %2:sta (%3)</translation>
+        <translation>%1% %2:sta (%3)</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Done</source>
-        <translation type="unfinished">Valmis</translation>
+        <translation>Valmis</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source</source>
-        <translation type="unfinished">Lähde</translation>
+        <translation>Lähde</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Destination</source>
-        <translation type="unfinished">Kohde</translation>
+        <translation>Kohde</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">Peru</translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Close</source>
-        <translation type="unfinished">Sulje</translation>
+        <translation>Sulje</translation>
     </message>
 </context>
 <context>
@@ -300,37 +310,37 @@
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Copy Warning</source>
-        <translation type="unfinished">Varoitus (kopiointi)</translation>
+        <translation>Varoitus (kopiointi)</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source</source>
-        <translation type="unfinished">Lähde</translation>
+        <translation>Lähde</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Destination</source>
-        <translation type="unfinished">Kohde</translation>
+        <translation>Kohde</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Skip</source>
-        <translation type="unfinished">Ohita</translation>
+        <translation>Ohita</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Overwrite</source>
-        <translation type="unfinished">Ylikirjoita</translation>
+        <translation>Ylikirjoita</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">Peru</translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Destination already exists.</source>
-        <translation type="unfinished">Kohdetiedosto on jo olemassa.</translation>
+        <translation>Kohdetiedosto on jo olemassa.</translation>
     </message>
 </context>
 <context>
@@ -338,37 +348,37 @@
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Preparing to delete %1 files</source>
-        <translation type="unfinished">Valmistellaan %1:n tiedoston poistoa</translation>
+        <translation>Valmistellaan %1:n tiedoston poistoa</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Deleting %1</source>
-        <translation type="unfinished">Poistetaan %1</translation>
+        <translation>Poistetaan %1</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Error deleting %1</source>
-        <translation type="unfinished">Virhe poistettaessa %1</translation>
+        <translation>Virhe poistettaessa %1</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Delete Finished Ok</source>
-        <translation type="unfinished">Poisto suoritettu Ok</translation>
+        <translation>Poisto suoritettu Ok</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Abort</source>
-        <translation type="unfinished">Keskeytä</translation>
+        <translation>Keskeytä</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Close</source>
-        <translation type="unfinished">Sulje</translation>
+        <translation>Sulje</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Deleting files</source>
-        <translation type="unfinished">Poistetaan tiedostoja</translation>
+        <translation>Poistetaan tiedostoja</translation>
     </message>
 </context>
 <context>
@@ -376,62 +386,62 @@
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Settings</source>
-        <translation type="unfinished">Asetukset</translation>
+        <translation>Asetukset</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Apply</source>
-        <translation type="unfinished">Toteuta</translation>
+        <translation>Toteuta</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">Peru</translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Home folder</source>
-        <translation type="unfinished">Kotihakemisto</translation>
+        <translation>Kotihakemisto</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Icons Style</source>
-        <translation type="unfinished">Kuvaketyyli</translation>
+        <translation>Kuvaketyyli</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Text Editor</source>
-        <translation type="unfinished">Tekstieditori</translation>
+        <translation>Tekstieditori</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Enable root access (restart needed)</source>
-        <translation type="unfinished">Käytä root-oikeuksia (uudelleenkäynnistys tarvitaan)</translation>
+        <translation>Käytä root-oikeuksia (uudelleenkäynnistys tarvitaan)</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Show hidden files and folders</source>
-        <translation type="unfinished">Näytä piilotiedostot ja -hakemistot</translation>
+        <translation>Näytä piilotiedostot ja -hakemistot</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Show thumbnails for images</source>
-        <translation type="unfinished">Näytä kuvat pienoiskuvina</translation>
+        <translation>Näytä kuvat pienoiskuvina</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Show details for files</source>
-        <translation type="unfinished">Näytä tiedoston tiedot</translation>
+        <translation>Näytä tiedostojen tiedot</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Delete items from clipboard on Paste</source>
-        <translation type="unfinished">Poista tiedosto leikepöydältä liitettäessä</translation>
+        <translation>Poista tiedosto leikepöydältä liitettäessä</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Enable multiselection</source>
-        <translation type="unfinished">Salli monen tiedoston valitseminen</translation>
+        <translation>Salli monen tiedoston valitseminen</translation>
     </message>
 </context>
 <context>
@@ -439,27 +449,27 @@
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Create folder</source>
-        <translation type="unfinished">Luo hakemisto</translation>
+        <translation>Luo hakemisto</translation>
     </message>
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Enter new folder name</source>
-        <translation type="unfinished">Uuden hakemiston nimi</translation>
+        <translation>Uuden hakemiston nimi</translation>
     </message>
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">Peru</translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Accept</source>
-        <translation type="unfinished">Hyväksy</translation>
+        <translation>Hyväksy</translation>
     </message>
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Cannot create folder. Try another name.</source>
-        <translation type="unfinished">Hakemistoa ei voitu luoda. Kokeile toista nimeä.</translation>
+        <translation>Hakemistoa ei voitu luoda. Kokeile toista nimeä.</translation>
     </message>
 </context>
 <context>
@@ -467,27 +477,27 @@
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Retry</source>
-        <translation type="unfinished">Yritä uudelleen</translation>
+        <translation>Yritä uudelleen</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">Peru</translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Skip</source>
-        <translation type="unfinished">Ohita</translation>
+        <translation>Ohita</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source</source>
-        <translation type="unfinished">Lähde</translation>
+        <translation>Lähde</translation>
     </message>
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Destination</source>
-        <translation type="unfinished">Kohde</translation>
+        <translation>Kohde</translation>
     </message>
 </context>
 <context>
@@ -495,27 +505,27 @@
     <message>
         <location filename="../rename.cpp" line="10"/>
         <source>Renaming</source>
-        <translation type="unfinished">Nimetään</translation>
+        <translation>Nimetään</translation>
     </message>
     <message>
         <location filename="../rename.cpp" line="10"/>
         <source>Enter new name</source>
-        <translation type="unfinished">Anna uusi nimi</translation>
+        <translation>Anna uusi nimi</translation>
     </message>
     <message>
         <location filename="../rename.cpp" line="10"/>
         <source>Accept</source>
-        <translation type="unfinished">Hyväksy</translation>
+        <translation>Hyväksy</translation>
     </message>
     <message>
         <location filename="../rename.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">Peru</translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../rename.cpp" line="10"/>
         <source>Cannot rename. Try another name.</source>
-        <translation type="unfinished">Ei voitu uudelleennimetä. Kokeile toista nimeä.</translation>
+        <translation>Ei voitu uudelleennimetä. Kokeile toista nimeä.</translation>
     </message>
 </context>
 <context>
@@ -523,27 +533,27 @@
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Deleting</source>
-        <translation type="unfinished">Poistetaan</translation>
+        <translation>Poistetaan</translation>
     </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Are you sure you want to delete %1?</source>
-        <translation type="unfinished">Haluatko poistaa %1:n?</translation>
+        <translation>Haluatko poistaa %1:n?</translation>
     </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Are you sure you want to delete selected files?</source>
-        <translation type="unfinished">Haluatko poistaa valitut tiedostot?</translation>
+        <translation>Haluatko poistaa valitut tiedostot?</translation>
     </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Yes</source>
-        <translation type="unfinished">Kyllä</translation>
+        <translation>Kyllä</translation>
     </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>No</source>
-        <translation type="unfinished">Ei</translation>
+        <translation>Ei</translation>
     </message>
 </context>
 <context>
@@ -551,37 +561,37 @@
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Sort</source>
-        <translation type="unfinished">Järjestä</translation>
+        <translation>Järjestä</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Name (A-Z)</source>
-        <translation type="unfinished">Nimi (A-Z)</translation>
+        <translation>Nimi (A-Z)</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Name (Z-A)</source>
-        <translation type="unfinished">Nimi (Z-A)</translation>
+        <translation>Nimi (Z-A)</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Date (olders first)</source>
-        <translation type="unfinished">Päiväys (vanhin ensin)</translation>
+        <translation>Päiväys (vanhin ensin)</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Date (recents first)</source>
-        <translation type="unfinished">Päiväys (uusin ensin)</translation>
+        <translation>Päiväys (uusin ensin)</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Size (smallers first)</source>
-        <translation type="unfinished">Koko (pienin ensin)</translation>
+        <translation>Koko (pienin ensin)</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Size (biggers first)</source>
-        <translation type="unfinished">Koko (suurin ensin)</translation>
+        <translation>Koko (suurin ensin)</translation>
     </message>
 </context>
 <context>
@@ -589,37 +599,37 @@
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>New document</source>
-        <translation type="unfinished">Uusi dokumentti</translation>
+        <translation>Uusi dokumentti</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>Create</source>
-        <translation type="unfinished">Luo</translation>
+        <translation>Luo</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">Peru</translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>Enter name for new document</source>
-        <translation type="unfinished">Anna uuden dokumentin nimi</translation>
+        <translation>Anna uuden dokumentin nimi</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>Enter a valid file name</source>
-        <translation type="unfinished">Anna sopiva nimi</translation>
+        <translation>Anna sopiva nimi</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>The file already exists. Try another name</source>
-        <translation type="unfinished">Tiedosto on jo olemassa. Kokeile toista nimeä</translation>
+        <translation>Tiedosto on jo olemassa. Kokeile toista nimeä</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>Cannot create the file. Check permissions</source>
-        <translation type="unfinished">Tiedostoa ei voitu luoda. Tarkista oikeudet</translation>
+        <translation>Tiedostoa ei voitu luoda. Tarkista oikeudet</translation>
     </message>
 </context>
 <context>
@@ -627,12 +637,12 @@
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Error</source>
-        <translation type="unfinished">Virhe</translation>
+        <translation>Virhe</translation>
     </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Accept</source>
-        <translation type="unfinished">Hyväksy</translation>
+        <translation>Hyväksy</translation>
     </message>
 </context>
 <context>
@@ -640,47 +650,47 @@
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Compress</source>
-        <translation type="unfinished">Pakkaa</translation>
+        <translation>Pakkaa</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>File name</source>
-        <translation type="unfinished">Tiedoston nimi</translation>
+        <translation>Tiedoston nimi</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Compression</source>
-        <translation type="unfinished">Pakkausmetodi</translation>
+        <translation>Pakkaus</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Destination folder</source>
-        <translation type="unfinished">Kohdehakemisto</translation>
+        <translation>Kohdehakemisto</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Accept</source>
-        <translation type="unfinished">Hyväksy</translation>
+        <translation>Hyväksy</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">Peru</translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>The file already exists. Try another name.</source>
-        <translation type="unfinished">Tiedosto on jo olemassa. Kokeile toista nimeä.</translation>
+        <translation>Tiedosto on jo olemassa. Kokeile toista nimeä.</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Not enough space to proceed.</source>
-        <translation type="unfinished">Ei tilaa toiminnon suoritukselle.</translation>
+        <translation>Ei tilaa toiminnon suoritukselle.</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
-        <source>You don't have permissions to proceed.</source>
-        <translation type="unfinished">Ei oikeuksia toiminnon suoritukselle.</translation>
+        <source>You don&apos;t have permissions to proceed.</source>
+        <translation>Ei oikeuksia toiminnon suoritukselle.</translation>
     </message>
 </context>
 <context>
@@ -688,27 +698,119 @@
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Compressing</source>
-        <translation type="unfinished">Pakataan</translation>
+        <translation>Pakataan</translation>
     </message>
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Adding %1...</source>
-        <translation type="unfinished">Lisätään %1...</translation>
+        <translation>Lisätään %1...</translation>
     </message>
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Operation finished.</source>
-        <translation type="unfinished">Toiminto suoritettu.</translation>
+        <translation>Toiminto suoritettu.</translation>
     </message>
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">Peru</translation>
+        <translation>Peru</translation>
     </message>
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Close</source>
-        <translation type="unfinished">Sulje</translation>
+        <translation>Sulje</translation>
+    </message>
+</context>
+<context>
+    <name>Unzip</name>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>Extract files</source>
+        <translation>Pura tiedostoja</translation>
+    </message>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation>Peru</translation>
+    </message>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>Not enough space to proceed.</source>
+        <translation>Ei tilaa toiminnon suoritukselle.</translation>
+    </message>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>You don&apos;t have permissions to proceed.</source>
+        <translation>Ei oikeuksia toiminnon suoritukselle.</translation>
+    </message>
+</context>
+<context>
+    <name>UnzipDlg</name>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Extract</source>
+        <translation>Pura</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Destination folder</source>
+        <translation>Kohdehakemisto</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Keep existing files</source>
+        <translation>Säilytä jo olevat tiedostot</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Accept</source>
+        <translation>Hyväksy</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation>Peru</translation>
+    </message>
+</context>
+<context>
+    <name>Extract</name>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Extracting</source>
+        <translation>Puretaan</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Extracting %1...</source>
+        <translation>Puretaan %1...</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Operation finished.</source>
+        <translation>Purkaminen suoritettu.</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation>Peru</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Close</source>
+        <translation>Sulje</translation>
+    </message>
+</context>
+<context>
+    <name>About</name>
+    <message>
+        <location filename="../about.cpp" line="10"/>
+        <source>About FileBox</source>
+        <translation>Tietoja FileBoxista</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="10"/>
+        <source>File Manager for Maemo 5</source>
+        <translation>Tiedostoselain Maemo 5:lle</translation>
     </message>
 </context>
 </TS>
