@@ -704,7 +704,7 @@
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Adding %1...</source>
-        <translation type="unfinished">Ajout de %1 ...</translation>
+        <translation>Ajout de 1% ...</translation>
     </message>
     <message>
         <location filename="../compress.cpp" line="10"/>
