@@ -163,6 +163,11 @@
         <source>Create new document</source>
         <translation type="unfinished">Crear nuevo documento</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Open terminal here</source>
+        <translation type="unfinished">Abrir terminal aquí</translation>
+    </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
@@ -448,6 +453,11 @@
         <source>Enable multiselection</source>
         <translation type="unfinished">Habilitar multiselección</translation>
     </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Autoselect items in clipboard</source>
+        <translation type="unfinished">Autoseleccionar ítems del portapapeles</translation>
+    </message>
 </context>
 <context>
     <name>NewFolder</name>
